<?php

use Tygh\Registry;
use Tygh\Http;
use Tygh\Settings;

function fn_redesk_multivendor_connection_get_departments()
{
	$url = Registry::get('settings.redesk_connection_multivendor.general.redesk_url');
	$api_key = Registry::get('settings.redesk_connection_multivendor.general.api_key');

	Registry::registerCache('redesk_departments', 600, Registry::cacheLevel('time'));
	$departments = Registry::get('redesk_departments');

	if ($url && $api_key && (Registry::isExist('redesk_departments') == false || empty($departments)))
	{
		$req = Http::get($url . 'api/getDepartments', array ('api_key' => $api_key));
		$departments = json_decode($req, true);

		Registry::set('redesk_departments', $departments);
	}

	return $departments;
}

function fn_redesk_multivendor_create_ticket($ticket)
{
	$url = Registry::get('settings.redesk_connection_multivendor.general.redesk_url');
	$api_key = Registry::get('settings.redesk_connection_multivendor.general.api_key');

	$ticket['api_key'] = $api_key;

	$post = $ticket;

	if (!empty($ticket['order_id']))
	{
		$company_id = db_get_field("SELECT company_id FROM ?:orders WHERE order_id = ?i", $ticket['order_id']);

		if (!empty($company_id))
			$post['company_id'] = $company_id;
	}

	$files = fn_filter_uploaded_data('redesk_files');

	if (!empty($files))
	{
		foreach ($files as $k => $file)
			$post['file_' . $k] = curl_file_create($file['path'], $file['type'], $file['name']);
	}

	return fn_redesk_multivendor_send_request($url  . 'api/createTicket', $post);
}

function fn_redesk_multivendor_install()
{
	$section = Settings::instance()->getSectionByName('Image_verification');

	$setting_id = Settings::instance()->update(array(
		'name' =>           'use_for_re_desk',
		'section_id' =>     $section['section_id'],
		'edition_type' =>   'ROOT,ULT:VENDOR',
		'section_tab_id' => 0,
		'type' =>           'C',
		'position' =>       200,
		'is_global' =>      'Y',
		'handler' =>        ''
	), null, null, true);

	Settings::instance()->updateDescription(array (
		'value'     => fn_get_lang_var('use_for_re_desk'),
		'object_id' => $setting_id,
		'object_type' => Settings::SETTING_DESCRIPTION,
		'lang_code' => 'en'
	));
}

function fn_redesk_multivendor_uninstall()
{
	$setting_id = Settings::instance()->getId(
		'use_for_re_desk',
		'Image_verification'
	);

	return Settings::instance()->removeById($setting_id);
}

function fn_redesk_connection_multivendor_contact_form_info()
{
	$storefront_url = Registry::get('config.http_location');
	if (fn_allowed_for('ULTIMATE')) {
		if (Registry::get('runtime.company_id') || Registry::get('runtime.simple_ultimate')) {
			$company = Registry::get('runtime.company_data');
			$storefront_url = 'http://' . $company['storefront'];
		} else {
			$storefront_url = '';
		}
	}

	return __('redesk_connection_multivendor_contact_form_info', array(
		'[http_location]' => $storefront_url,
	));
}

function fn_redesk_connection_multivendor_update_company(&$company_data, &$company_id, &$lang_code, &$action)
{
	if ($action == 'add')
	{
		$url = Registry::get('settings.redesk_connection_multivendor.general.redesk_url');
		$api_key = Registry::get('settings.redesk_connection_multivendor.general.api_key');

		if (empty($url) || empty($api_key))
			return false;

		$post = array ('vendors' => array(array (
			'company_id' => $company_id,
			'company'	 => $company_data['company'],
			'lang_code'	 => $company_data['lang_code'],
			'email'		 => $company_data['email'],
		)));

		$post['create_accounts'] = 1;
		$post['api_key'] = $api_key;
		$post['vendors'] = json_encode($post['vendors']);

		fn_redesk_multivendor_send_request($url . 'api/syncVendors', $post);
	}

	return true;
}

function fn_redesk_multivendor_send_request($url, $post)
{
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
	curl_setopt($ch, CURLOPT_POST, 1);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
	curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 6.1; en-GB; rv:1.9.2) Gecko/20100115 Firefox/3.6 (.NET CLR 3.5.30729)");
	$req = curl_exec($ch);
	curl_close($ch);

	return $req;
}